import numpy as np

def counter(func):
    """
    A decorator that counts and prints the number of times a function has been executed
    """
    def wrapper(*args, **kwargs):
        wrapper.count = wrapper.count + 1
        out = func(*args, **kwargs)
        print('{0} has been used: {1}x'.format(func.__name__, wrapper.count))
        return out
    wrapper.count = 0
    return wrapper

@counter
def distance(x, y):
    d = np.sqrt(x**2.0 + y**2.0)
    return d


### Demo
# Calculate the Euclidean distance between three tuples stored in two lists.
xs = [1, 3, 5]
ys = [-5, -3, 1]
for x, y in zip(xs, ys):
    d = distance(x, y)
